# flake8: noqa

"""
    Login API

    For bots and other on-premise processes to authenticate. Once authenticated, the bot will be able to use the methods described in serviceAPI.yaml and agentAPI.yaml.  Authentication requests will expect the user to pass a token containing user identification information and signed by the user's private key  There will be two implementations of this API, one on your Pod and one on the Key Manager. In order to fully authenticate, an API client will have to call both of these implementations and pass both of the session tokens returned as headers in all subsequent requests to the Symphony API.   # noqa: E501

    The version of the OpenAPI document: 20.10.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from symphony.bdk.gen.api_client import ApiClient

# import Configuration
from symphony.bdk.gen.configuration import Configuration

# import exceptions
from symphony.bdk.gen.exceptions import OpenApiException
from symphony.bdk.gen.exceptions import ApiAttributeError
from symphony.bdk.gen.exceptions import ApiTypeError
from symphony.bdk.gen.exceptions import ApiValueError
from symphony.bdk.gen.exceptions import ApiKeyError
from symphony.bdk.gen.exceptions import ApiException
